{ pkgs, nix-config, ... }:

{

  home.packages = with pkgs; [
    appimage-run
    libappimage
    transmission_4-gtk
    wl-clipboard
    clipse
    maim
    wayland-utils
    libheif.out
    rpi-imager
    thonny
    freecad
    flatpak
    gst_all_1.gstreamer
    prusa-slicer
    via
    vial
    scribus
    pdfarranger
    tdf
    pdfchain
    pdftk
    zathura
    gpu-viewer

    wl-mirror

    soundconverter
    wmctrl
    colloid-icon-theme
    whitesur-gtk-theme
    whitesur-cursors
    whitesur-icon-theme
    bibata-cursors
    adwaita-qt

    godot_4
    gdtoolkit_4
    sane-airscan
    xsane

    bitwarden-cli
    bitwarden-desktop
    tailscale
    trayscale
    font-manager

    squirreldisk
    papers
    newsflash

    stirling-pdf
    ripdrag

    sway-launcher-desktop
    swayosd

    thunderbird-latest
    emojify
    smile

    impression
    zoom-us
    nyxt
    ungoogled-chromium
    obsidian
    vlc
    polychromatic
    discord
    slack
    signal-desktop
    eyedropper
    onlyoffice-desktopeditors
    libreoffice
    hyphenDicts.en_US
    plex-mpv-shim
    plexamp
    plex-media-player

    switcheroo

    blender
    davinci-resolve-studio
    steam
    processing
    zotero
    fractal
    handbrake
    krita
    rawtherapee
    inkscape
    gimp
    epsonscan2
    kicad
    turbocase
    openscad-unstable
    openscad-lsp
    picard
    evolutionWithPlugins
    plugdata
    pavucontrol
    qpwgraph
    helvum
    coppwr
    clapper
    ardour
    oculante
    farge
    halloy
    paleta
    wayback
    protonplus
    fstl

    wineWowPackages.stagingFull
    winetricks
  ];

  home.pointerCursor = {
    package = pkgs.rice.cursor.package;
    name = pkgs.rice.cursor.name;
    size = 24;
    gtk.enable = true;
    x11.enable = true;
  };

  gtk.cursorTheme = pkgs.rice.cursor;

  fonts = {
    fontconfig = {
      enable = true;
    };
  };

  services.flatpak = {
    enable = true;
    packages = [
      "com.github.tchx84.Flatseal"
      "dev.qwery.AddWater"
    ];
  };

  services.swaync = {
    enable = true;
    settings = {
      positionX = "right";
      positionY = "top";
      layer = "overlay";
      control-center-layer = "top";
      layer-shell = true;
      cssPriority = "application";
      control-center-margin-top = 0;
      control-center-margin-bottom = 0;
      control-center-margin-right = 0;
      control-center-margin-left = 0;
      notification-2fa-action = true;
      notification-inline-replies = false;
      notification-icon-size = 64;
      notification-body-image-height = 100;
      notification-body-image-width = 200;
    };
    style =
''
  .notification-row {
    outline: none;
  }

  .notification-row:focus,
  .notification-row:hover {
    background: @noti-bg-focus;
  }

  .notification {
    border-radius: 12px;
    margin: 6px 12px;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.3), 0 1px 3px 1px rgba(0, 0, 0, 0.7),
      0 2px 6px 2px rgba(0, 0, 0, 0.3);
    padding: 0;
  }
'';
  };

  programs = {
    eww = {
      enable = true;
      configDir = ../../homes/emenel/dotfiles/dot_config/eww;
    };
    firefox.enable = true;
  };

  xdg.configFile."halloy/config.toml".source =
    ../../homes/emenel/dotfiles/dot_config/halloy/config.toml;

}
